@@ -6,9 +6,13 @@
  */
 
 #pragma once
-
 #include "grantleetheme_export.h"
+#include <QObject>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <grantlee/qtlocalizer.h>
+#else
+#include <KTextTemplate/QtLocalizer>
+#endif
 
 #include <QLocale>
 #include <QVariantHash>
@@ -19,7 +23,11 @@ namespace GrantleeTheme
 /**
  * @brief The GrantleeKi18nLocalizer class
  */
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 class GRANTLEETHEME_EXPORT GrantleeKi18nLocalizer : public Grantlee::QtLocalizer
+#else
+class GRANTLEETHEME_EXPORT GrantleeKi18nLocalizer : public KTextTemplate::QtLocalizer
+#endif
 {
 public:
     explicit GrantleeKi18nLocalizer();
@@ -44,8 +52,7 @@ public:
     void setApplicationDomain(const QByteArray &domain);
 
 private:
-    QString processArguments(const KLocalizedString &str, const QVariantList &arguments) const;
+    Q_REQUIRED_RESULT QString processArguments(const KLocalizedString &str, const QVariantList &arguments) const;
     QByteArray mApplicationDomain;
 };
 }
-
